==> qtjambi-qt3dcore-6.2.12-sources.jar: io/qt/qt3d/core/QNodeIdTypePair.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class Qt3DCore::QNodeIdTypePair</p>
 */
public class QNodeIdTypePair extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QNodeIdTypePair(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance);
    
    public QNodeIdTypePair(io.qt.qt3d.core.@NonNull QNodeId _id, io.qt.core.@Nullable QMetaObject _type){
        super((QPrivateConstructor)null);
        initialize_native(this, _id, _type);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance, io.qt.qt3d.core.QNodeId _id, io.qt.core.QMetaObject _type);
    
    @QtUninvokable
    public final void setId(io.qt.qt3d.core.@NonNull QNodeId id){
        setId_native_cref_Qt3DCore_QNodeId(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @QtUninvokable
    private native void setId_native_cref_Qt3DCore_QNodeId(long __this__nativeId, long id);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #id()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId getId() {
        return id();
    }
    
    @QtUninvokable
    public final io.qt.qt3d.core.@NonNull QNodeId id(){
        return id_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.qt3d.core.QNodeId id_native(long __this__nativeId);
    
    @QtUninvokable
    public final void setType(io.qt.core.@Nullable QMetaObject type){
        setType_native_const_QMetaObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), type);
    }
    
    @QtUninvokable
    private native void setType_native_const_QMetaObject_ptr(long __this__nativeId, io.qt.core.QMetaObject type);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #type()} instead.</p>
     */
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject getType() {
        return type();
    }
    
    @QtUninvokable
    public final io.qt.core.@Nullable QMetaObject type(){
        return type_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QMetaObject type_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNodeIdTypePair(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QNodeIdTypePair clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNodeIdTypePair clone_native(long __this_nativeId);
}

==> qtjambi-qt3dcore-6.4.3-sources.jar: io/qt/qt3d/core/QNodeIdTypePair.java <==
package io.qt.qt3d.core;


/**
 * <p>Java wrapper for Qt class Qt3DCore::QNodeIdTypePair</p>
 */
public class QNodeIdTypePair extends io.qt.QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QNodeIdTypePair(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance);
    
    public QNodeIdTypePair(io.qt.qt3d.core.QNodeId _id, io.qt.core.QMetaObject _type){
        super((QPrivateConstructor)null);
        initialize_native(this, _id, _type);
    }
    
    private native static void initialize_native(QNodeIdTypePair instance, io.qt.qt3d.core.QNodeId _id, io.qt.core.QMetaObject _type);
    
    @io.qt.QtUninvokable
    public final void setId(io.qt.qt3d.core.QNodeId id){
        setId_native_cref_Qt3DCore_QNodeId(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(id));
    }
    
    @io.qt.QtUninvokable
    private native void setId_native_cref_Qt3DCore_QNodeId(long __this__nativeId, long id);
    
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNodeId id(){
        return id_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNodeId id_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setType(io.qt.core.QMetaObject type){
        setType_native_const_QMetaObject_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), type);
    }
    
    @io.qt.QtUninvokable
    private native void setType_native_const_QMetaObject_ptr(long __this__nativeId, io.qt.core.QMetaObject type);
    
    @io.qt.QtUninvokable
    public final io.qt.core.QMetaObject type(){
        return type_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QMetaObject type_native(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QNodeIdTypePair(QPrivateConstructor p) { super(p); } 
    
    
    @Override
    public QNodeIdTypePair clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private native QNodeIdTypePair clone_native(long __this_nativeId);
}
